import adafruit_fancyled.adafruit_fancyled as fancy
import board, neopixel, time, adafruit_lis3dh, busio, digitalio
from adafruit_led_animation.animation.SparklePulse import SparklePulse

from audiopwmio import PWMAudioOut as AudioOut
from audiocore import WaveFile

# set up the speaker
speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.A3)

i2c = busio.I2C(board.ACCELEROMETER_SCL, board.ACCELEROMETER_SDA)
int1 = digitalio.DigitalInOut(board.ACCELEROMETER_INTERRUPT)
accelerometer = adafruit_lis3dh.LIS3DH_I2C(i2c, address=0x19, int1=int1)
accelerometer.range = adafruit_lis3dh.RANGE_8_G

winter_color = fancy.CRGB(169, 245, 231)
spring_color = fancy.CRGB(20, 255, 0)
summer_color = fancy.CRGB(195, 160, 60)
autumn_color = fancy.CRGB(205, 100, 50)

AMBER = (255, 100, 0)

season_palette = [winter_color, spring_color, summer_color, autumn_color]

strip = neopixel.NeoPixel(board.A1, 30)
strip2 = neopixel.NeoPixel(board.A4, 20)

levels = (.25, .3, .15)

min_ratio = .01
max_ratio = 100
ratio_range = max_ratio - min_ratio

sparkle_pulse_strip = SparklePulse(strip2, speed=.1, period=5, color=AMBER)

def winter(x, y):
    with open("seasons/winter-winds-7077.wav", "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            x, y, z = accelerometer.acceleration
            if x == 0 or y == 0:
                audio.stop()
                break
            ratio = (-y/x) ** 2
            if ratio < min_ratio:
                color = fancy.palette_lookup(season_palette, .875)
            elif ratio > max_ratio:
                color = fancy.palette_lookup(season_palette, 1.125)
            else:
                color = fancy.palette_lookup(season_palette, (ratio - min_ratio) / ratio_range * .25 + .875)
            color = fancy.gamma_adjust(color, brightness = levels)
            strip.fill(color.pack())

def spring(x, y):
    with open("seasons/birds_singing-6888.wav", "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            x, y, z = accelerometer.acceleration
            if x == 0 or y == 0:
                audio.stop()
                break
            ratio = (x/y) ** 2
            if ratio < min_ratio:
                color = fancy.palette_lookup(season_palette, .125)
            elif ratio > max_ratio:
                color = fancy.palette_lookup(season_palette, .375)
            else:
                color = fancy.palette_lookup(season_palette, (ratio - min_ratio) / ratio_range * .25 + .125)
            color = fancy.gamma_adjust(color, brightness = levels)
            strip.fill(color.pack())

def summer(x, y):
    with open("seasons/forest_cicada_loop-6031.wav", "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            x, y, z = accelerometer.acceleration
            if x == 0 or y == 0:
                audio.stop()
                break
            ratio = (-y/x) ** 2
            if ratio < min_ratio:
                color = fancy.palette_lookup(season_palette, .375)
            elif ratio > max_ratio:
                color = fancy.palette_lookup(season_palette, .625)
            else:
                color = fancy.palette_lookup(season_palette, (ratio - min_ratio) / ratio_range * .25 + .375)
            color = fancy.gamma_adjust(color, brightness = levels)
            strip.fill(color.pack())

def autumn(x, y):
    with open("seasons/oak-grove-dry-leaves-autumn-9520.wav", "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            x, y, z = accelerometer.acceleration
            if x == 0 or y == 0:
                audio.stop()
                break
            ratio = (x/y) ** 2
            if ratio < min_ratio:
                color = fancy.palette_lookup(season_palette, .625)
            elif ratio > max_ratio:
                color = fancy.palette_lookup(season_palette, .875)
            else:
                color = fancy.palette_lookup(season_palette, (ratio - min_ratio) / ratio_range * .25 + .625)
            color = fancy.gamma_adjust(color, brightness = levels)
            strip.fill(color.pack())

while True:
    x, y, z = accelerometer.acceleration
    #Winter
    if x > 0 and y > 0:
        winter(x, y)
    #Spring
    elif x < 0 and y > 0:
        spring(x, y)
    #Summer
    elif x < 0 and y < 0:
        summer(x, y)
    #Fall
    elif x > 0 and y < 0:
        autumn(x, y)
    sparkle_pulse_strip.animate()

